==> haskell-pattern-arrows-0.0.2-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pattern-arrows.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pattern-arrows
version:              0.0.2
visibility:           public
id:                   pattern-arrows-0.0.2-L08UhuuDsp27qvWxA5hze3
key:                  pattern-arrows-0.0.2-L08UhuuDsp27qvWxA5hze3
license:              MIT
copyright:            (c) Phil Freeman 2013
maintainer:           Phil Freeman <paf31@cantab.net>
author:               Phil Freeman <paf31@cantab.net>
stability:            experimental
homepage:
    http://blog.functorial.com/posts/2013-10-27-Pretty-Printing-Arrows.html

synopsis:             Arrows for Pretty Printing
description:
    A library for generating concise pretty printers based on precedence rules.

category:             Text, Combinators, Pretty Printer
abi:                  8c48a5763d7f02a1a5d6444da9704ffe
exposed:              True
exposed-modules:      Control.PatternArrows
import-dirs:          /usr/lib/ghc-8.10.1/site-local/pattern-arrows-0.0.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/pattern-arrows-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/pattern-arrows-0.0.2
hs-libraries:         HSpattern-arrows-0.0.2-L08UhuuDsp27qvWxA5hze3
depends:              base-4.14.0.0 mtl-2.2.2
haddock-interfaces:
    /usr/share/doc/haskell-pattern-arrows/html/pattern-arrows.haddock

haddock-html:         /usr/share/doc/haskell-pattern-arrows/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pattern-arrows-0.0.2-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pattern-arrows.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pattern-arrows
version:              0.0.2
visibility:           public
id:                   pattern-arrows-0.0.2-388AH1HwYyCFNZxGqaEGz3
key:                  pattern-arrows-0.0.2-388AH1HwYyCFNZxGqaEGz3
license:              MIT
copyright:            (c) Phil Freeman 2013
maintainer:           Phil Freeman <paf31@cantab.net>
author:               Phil Freeman <paf31@cantab.net>
stability:            experimental
homepage:
    http://blog.functorial.com/posts/2013-10-27-Pretty-Printing-Arrows.html

synopsis:             Arrows for Pretty Printing
description:
    A library for generating concise pretty printers based on precedence rules.

category:             Text, Combinators, Pretty Printer
abi:                  72f2869d068e709f1908fe0ae815b872
exposed:              True
exposed-modules:      Control.PatternArrows
import-dirs:          /usr/lib/ghc-8.10.2/site-local/pattern-arrows-0.0.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/pattern-arrows-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/pattern-arrows-0.0.2
hs-libraries:         HSpattern-arrows-0.0.2-388AH1HwYyCFNZxGqaEGz3
depends:              base-4.14.1.0 mtl-2.2.2
haddock-interfaces:
    /usr/share/doc/haskell-pattern-arrows/html/pattern-arrows.haddock

haddock-html:         /usr/share/doc/haskell-pattern-arrows/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
